@@ -1,5 +1,4 @@
 import typing
-import time
 
 from . import objects
 
@@ -27,40 +26,21 @@ class Broker:
     def number_of_enqueued_tasks(
         self,
         task_name: str,
+        consumable_only: bool,
     ) -> int:
         number_of_enqueued_tasks = self.connector.queue_length(
             queue_name=task_name,
+            consumable_only=consumable_only,
         )
 
         return number_of_enqueued_tasks
 
-    def wait_queue_empty(
-        self,
-        task_name: str,
-        timeout: float = 0,
-        sample_interval: float = 1.0,
-    ) -> bool:
-        remaining_time = timeout
-
-        not_empty = True
-        while not_empty:
-            if timeout and remaining_time <= 0:
-                return False
-
-            not_empty = self.number_of_enqueued_tasks(
-                task_name=task_name,
-            ) != 0
-
-            time.sleep(sample_interval)
-            remaining_time -= sample_interval
-
-        return True
-
     def push_task(
         self,
         task_name: str,
         task: objects.Task,
         priority: str = 'NORMAL',
+        consumable_from: int = 0,
     ) -> bool:
         encoded_item = self.encoder.encode(
             data=task,
@@ -70,6 +50,7 @@ class Broker:
             queue_name=task_name,
             item=encoded_item,
             priority=priority,
+            consumable_from=consumable_from,
         )
 
         return pushed
@@ -79,6 +60,7 @@ class Broker:
         task_name: str,
         tasks: typing.Iterable[objects.Task],
         priority: str = 'NORMAL',
+        consumable_from: int = 0,
     ) -> bool:
         encoded_tasks = []
         for task in tasks:
@@ -93,6 +75,7 @@ class Broker:
                 queue_name=task_name,
                 items=encoded_tasks,
                 priority=priority,
+                consumable_from=consumable_from,
             )
 
         return True
@@ -130,6 +113,7 @@ class Broker:
         task_name: str,
         task: objects.Task,
         priority: str = 'NORMAL',
+        consumable_from: int = 0,
     ) -> bool:
         task.run_count += 1
 
@@ -137,6 +121,7 @@ class Broker:
             task_name=task_name,
             task=task,
             priority=priority,
+            consumable_from=consumable_from,
         )
 
     def requeue(
@@ -144,11 +129,13 @@ class Broker:
         task_name: str,
         task: objects.Task,
         priority='NORMAL',
+        consumable_from: int = 0,
     ) -> bool:
         return self.push_task(
             task_name=task_name,
             task=task,
             priority=priority,
+            consumable_from=consumable_from,
         )
 
     def delete_key(
