@@ -3,7 +3,9 @@ import dataclasses
 import typing
 
 
-@dataclasses.dataclass
+@dataclasses.dataclass(
+    frozen=True,
+)
 class LoggingEvents:
     on_success: bool = False
     on_failure: bool = True
@@ -11,9 +13,12 @@ class LoggingEvents:
     on_retry: bool = True
     on_max_retries: bool = True
     on_requeue: bool = True
+    on_starvation: bool = True
 
 
-@dataclasses.dataclass
+@dataclasses.dataclass(
+    frozen=True,
+)
 class Logging:
     level: int = logging.ERROR
     log_to_stdout: bool = False
@@ -25,32 +30,49 @@ class Logging:
     )
 
 
-@dataclasses.dataclass
+@dataclasses.dataclass(
+    frozen=True,
+)
 class Encoder:
     compressor: typing.Optional[str] = None
     serializer: str = 'pickle'
 
 
-@dataclasses.dataclass
+@dataclasses.dataclass(
+    frozen=True,
+)
 class Connector:
     type: str
     params: typing.Dict[str, typing.Any]
 
 
-@dataclasses.dataclass
+@dataclasses.dataclass(
+    frozen=True,
+)
 class Executor:
     type: str = 'serial'
     number_of_threads: int = 1
 
 
-@dataclasses.dataclass
+@dataclasses.dataclass(
+    frozen=True,
+)
 class Timeouts:
     soft_timeout: float = 0.0
     hard_timeout: float = 0.0
     critical_timeout: float = 0.0
 
 
-@dataclasses.dataclass
+@dataclasses.dataclass(
+    frozen=True,
+)
+class Starvation:
+    time_with_no_tasks: int
+
+
+@dataclasses.dataclass(
+    frozen=True,
+)
 class WorkerConfig:
     name: str
     connector: Connector
@@ -69,3 +91,15 @@ class WorkerConfig:
     logging: Logging = dataclasses.field(
         default_factory=Logging,
     )
+    starvation: typing.Optional[Starvation] = None
+
+    def replace(
+        self,
+        *args,
+        **kwargs,
+    ):
+        return dataclasses.replace(
+            self,
+            *args,
+            **kwargs,
+        )
