@@ -100,10 +100,12 @@ class Worker:
     def number_of_enqueued_tasks(
         self,
         task_name: typing.Optional[str] = None,
+        consumable_only: bool = False,
     ) -> typing.Optional[int]:
         try:
             return self.broker.number_of_enqueued_tasks(
                 task_name=task_name if task_name else self.config.name,
+                consumable_only=consumable_only,
             )
         except Exception as exception:
             self.logger.error(
@@ -117,6 +119,7 @@ class Worker:
         kwargs: typing.Dict[str, typing.Any],
         task_name: typing.Optional[str] = None,
         priority: str = 'NORMAL',
+        consumable_from: int = 0,
     ) -> bool:
         try:
             task = objects.Task(
@@ -127,6 +130,7 @@ class Worker:
                 task_name=task_name if task_name else self.config.name,
                 task=task,
                 priority=priority,
+                consumable_from=consumable_from,
             )
 
             return True
@@ -142,6 +146,7 @@ class Worker:
         kwargs_list: typing.Iterable[typing.Dict[str, typing.Any]],
         task_name: typing.Optional[str] = None,
         priority: str = 'NORMAL',
+        consumable_from: int = 0,
     ) -> bool:
         try:
             tasks = [
@@ -155,6 +160,7 @@ class Worker:
                 task_name=task_name if task_name else self.config.name,
                 tasks=tasks,
                 priority=priority,
+                consumable_from=consumable_from,
             )
         except Exception as exception:
             self.logger.error(
@@ -228,26 +234,23 @@ class Worker:
                 time_with_no_tasks = 0
 
             try:
-                iterated_tasks = 0
-                for task in tasks:
+                for iterated_tasks, task in enumerate(tasks):
                     yield task
-
-                    iterated_tasks += 1
-
-                if not run_forever:
-                    tasks_left -= number_of_dequeued_tasks
             except Exception as exception:
                 if tasks:
                     self.push_tasks(
                         kwargs_list=[
                             task.kwargs
-                            for task in tasks[iterated_tasks + 1:]
+                            for task in tasks[iterated_tasks:]
                         ],
                         priority='HIGH',
                     )
 
                 raise exception
 
+            if not run_forever:
+                tasks_left -= number_of_dequeued_tasks
+
     def work_loop(
         self,
     ) -> typing.Dict[str, typing.Any]:
@@ -312,6 +315,7 @@ class Worker:
         self,
         task: objects.Task,
         priority: str = 'NORMAL',
+        consumable_from: int = 0,
     ) -> None:
         if self.config.max_retries > 0 and self.config.max_retries <= task.run_count:
             raise WorkerMaxRetries()
@@ -320,6 +324,7 @@ class Worker:
                 task_name=self.config.name,
                 task=task,
                 priority=priority,
+                consumable_from=consumable_from,
             )
 
             raise WorkerRetry()
@@ -328,11 +333,13 @@ class Worker:
         self,
         task: objects.Task,
         priority: str = 'NORMAL',
+        consumable_from: int = 0,
     ) -> None:
         self.broker.requeue(
             task_name=self.config.name,
             task=task,
             priority=priority,
+            consumable_from=consumable_from,
         )
 
         raise WorkerRequeue()
